==> homeassistant-2025.10.0b4.tar.gz: homeassistant-2025.10.0b4/homeassistant/components/music_assistant/const.py <==
"""Constants for Music Assistant Component."""

import logging

DOMAIN = "music_assistant"
DOMAIN_EVENT = f"{DOMAIN}_event"

DEFAULT_NAME = "Music Assistant"

ATTR_IS_GROUP = "is_group"
ATTR_GROUP_MEMBERS = "group_members"
ATTR_GROUP_PARENTS = "group_parents"

ATTR_MASS_PLAYER_TYPE = "mass_player_type"
ATTR_ACTIVE_QUEUE = "active_queue"
ATTR_STREAM_TITLE = "stream_title"
ATTR_MEDIA_TYPE = "media_type"
ATTR_SEARCH_NAME = "name"
ATTR_SEARCH_ARTIST = "artist"
ATTR_SEARCH_ALBUM = "album"
ATTR_LIMIT = "limit"
ATTR_LIBRARY_ONLY = "library_only"
ATTR_FAVORITE = "favorite"
ATTR_SEARCH = "search"
ATTR_OFFSET = "offset"
ATTR_ORDER_BY = "order_by"
ATTR_ALBUM_TYPE = "album_type"
ATTR_ALBUM_ARTISTS_ONLY = "album_artists_only"
ATTR_URI = "uri"
ATTR_IMAGE = "image"
ATTR_VERSION = "version"
ATTR_ARTISTS = "artists"
ATTR_ALBUMS = "albums"
ATTR_TRACKS = "tracks"
ATTR_PLAYLISTS = "playlists"
ATTR_AUDIOBOOKS = "audiobooks"
ATTR_PODCASTS = "podcasts"
ATTR_RADIO = "radio"
ATTR_ITEMS = "items"
ATTR_RADIO_MODE = "radio_mode"
ATTR_MEDIA_ID = "media_id"
ATTR_ARTIST = "artist"
ATTR_ALBUM = "album"
ATTR_URL = "url"
ATTR_USE_PRE_ANNOUNCE = "use_pre_announce"
ATTR_ANNOUNCE_VOLUME = "announce_volume"
ATTR_SOURCE_PLAYER = "source_player"
ATTR_AUTO_PLAY = "auto_play"
ATTR_QUEUE_ID = "queue_id"
ATTR_ACTIVE = "active"
ATTR_SHUFFLE_ENABLED = "shuffle_enabled"
ATTR_REPEAT_MODE = "repeat_mode"
ATTR_CURRENT_INDEX = "current_index"
ATTR_ELAPSED_TIME = "elapsed_time"
ATTR_CURRENT_ITEM = "current_item"
ATTR_NEXT_ITEM = "next_item"
ATTR_QUEUE_ITEM_ID = "queue_item_id"
ATTR_DURATION = "duration"
ATTR_MEDIA_ITEM = "media_item"
ATTR_STREAM_DETAILS = "stream_details"
ATTR_CONTENT_TYPE = "content_type"
ATTR_SAMPLE_RATE = "sample_rate"
ATTR_BIT_DEPTH = "bit_depth"
ATTR_STREAM_TITLE = "stream_title"
ATTR_PROVIDER = "provider"
ATTR_ITEM_ID = "item_id"

ATTR_CONF_EXPOSE_PLAYER_TO_HA = "expose_player_to_ha"

LOGGER = logging.getLogger(__package__)

==> homeassistant-2025.11.0b6.tar.gz: homeassistant-2025.11.0b6/homeassistant/components/music_assistant/const.py <==
"""Constants for Music Assistant Component."""

import logging

DOMAIN = "music_assistant"
DOMAIN_EVENT = f"{DOMAIN}_event"

DEFAULT_NAME = "Music Assistant"

ATTR_IS_GROUP = "is_group"
ATTR_GROUP_MEMBERS = "group_members"
ATTR_GROUP_PARENTS = "group_parents"

ATTR_MASS_PLAYER_TYPE = "mass_player_type"
ATTR_ACTIVE_QUEUE = "active_queue"
ATTR_STREAM_TITLE = "stream_title"
ATTR_MEDIA_TYPE = "media_type"
ATTR_SEARCH_NAME = "name"
ATTR_SEARCH_ARTIST = "artist"
ATTR_SEARCH_ALBUM = "album"
ATTR_LIMIT = "limit"
ATTR_LIBRARY_ONLY = "library_only"
ATTR_FAVORITE = "favorite"
ATTR_SEARCH = "search"
ATTR_OFFSET = "offset"
ATTR_ORDER_BY = "order_by"
ATTR_ALBUM_TYPE = "album_type"
ATTR_ALBUM_ARTISTS_ONLY = "album_artists_only"
ATTR_URI = "uri"
ATTR_IMAGE = "image"
ATTR_VERSION = "version"
ATTR_ARTISTS = "artists"
ATTR_ALBUMS = "albums"
ATTR_TRACKS = "tracks"
ATTR_PLAYLISTS = "playlists"
ATTR_AUDIOBOOKS = "audiobooks"
ATTR_PODCASTS = "podcasts"
ATTR_RADIO = "radio"
ATTR_ITEMS = "items"
ATTR_RADIO_MODE = "radio_mode"
ATTR_MEDIA_ID = "media_id"
ATTR_ARTIST = "artist"
ATTR_ALBUM = "album"
ATTR_URL = "url"
ATTR_USE_PRE_ANNOUNCE = "use_pre_announce"
ATTR_ANNOUNCE_VOLUME = "announce_volume"
ATTR_SOURCE_PLAYER = "source_player"
ATTR_AUTO_PLAY = "auto_play"
ATTR_QUEUE_ID = "queue_id"
ATTR_ACTIVE = "active"
ATTR_SHUFFLE_ENABLED = "shuffle_enabled"
ATTR_REPEAT_MODE = "repeat_mode"
ATTR_CURRENT_INDEX = "current_index"
ATTR_ELAPSED_TIME = "elapsed_time"
ATTR_CURRENT_ITEM = "current_item"
ATTR_NEXT_ITEM = "next_item"
ATTR_QUEUE_ITEM_ID = "queue_item_id"
ATTR_DURATION = "duration"
ATTR_MEDIA_ITEM = "media_item"
ATTR_STREAM_DETAILS = "stream_details"
ATTR_CONTENT_TYPE = "content_type"
ATTR_SAMPLE_RATE = "sample_rate"
ATTR_BIT_DEPTH = "bit_depth"
ATTR_STREAM_TITLE = "stream_title"
ATTR_PROVIDER = "provider"
ATTR_ITEM_ID = "item_id"
ATTR_EXPLICIT = "explicit"
ATTR_BITRATE = "bit_rate"
ATTR_DISCART_IMAGE = "discart_image"
ATTR_FANART_IMAGE = "fanart_image"

ATTR_CONF_EXPOSE_PLAYER_TO_HA = "expose_player_to_ha"

LOGGER = logging.getLogger(__package__)
